summaryrefslogtreecommitdiff
path: root/forms/source/inc
diff options
context:
space:
mode:
authorMikhail Voytenko <mav@openoffice.org>2011-01-13 16:49:46 +0100
committerMikhail Voytenko <mav@openoffice.org>2011-01-13 16:49:46 +0100
commita6569df130ac16327e4f52498e9925e16f56bf10 (patch)
tree0f3f9b83ccfd13aab3f749d5121f907199120877 /forms/source/inc
parentdf0b31641237470028437efd959c355dc0f32953 (diff)
removetooltypes01: #i112600# remove tooltypes from slideshow and forms
Diffstat (limited to 'forms/source/inc')
-rw-r--r--forms/source/inc/FormComponent.hxx26
-rw-r--r--forms/source/inc/InterfaceContainer.hxx4
-rw-r--r--forms/source/inc/formnavigation.hxx2
-rw-r--r--forms/source/inc/urltransformer.hxx2
4 files changed, 17 insertions, 17 deletions
diff --git a/forms/source/inc/InterfaceContainer.hxx b/forms/source/inc/InterfaceContainer.hxx
index 90e508f43ca8..72466fb31e3f 100644
--- a/forms/source/inc/InterfaceContainer.hxx
+++ b/forms/source/inc/InterfaceContainer.hxx
@@ -211,12 +211,12 @@ protected:
@param _nIndex
the index at which position it should be inserted
@param _bEvents
- if <TRUE/>, event knittings will be done
+ if <sal_True/>, event knittings will be done
@param _pApprovalResult
must contain the result of an approveNewElement call. Can be <NULL/>, in this case, the approval
is done within implInsert.
@param _bFire
- if <TRUE/>, a notification about the insertion will be fired
+ if <sal_True/>, a notification about the insertion will be fired
*/
void implInsert(
sal_Int32 _nIndex,
diff --git a/forms/source/inc/formnavigation.hxx b/forms/source/inc/formnavigation.hxx
index 6dc848bd8abe..440d76bae7bd 100644
--- a/forms/source/inc/formnavigation.hxx
+++ b/forms/source/inc/formnavigation.hxx
@@ -208,7 +208,7 @@ namespace frm
@complexity O(log n), with n being the number of all potentially known URLs
@return
- <TRUE/> if and only if the given id is a known feature id
+ <sal_True/> if and only if the given id is a known feature id
(which is a valid usage)
*/
bool getFeatureURL( sal_Int16 _nFeatureId, ::com::sun::star::util::URL& /* [out] */ _rURL );
diff --git a/forms/source/inc/urltransformer.hxx b/forms/source/inc/urltransformer.hxx
index 2e8bdf1f684a..0231f983c1b3 100644
--- a/forms/source/inc/urltransformer.hxx
+++ b/forms/source/inc/urltransformer.hxx
@@ -73,7 +73,7 @@ namespace frm
/** ensures that we have an URLTransformer instance in <member>m_xTransformer</member>
@return
- <TRUE/> if and only if m_xTransformer is not <NULL/>
+ <sal_True/> if and only if m_xTransformer is not <NULL/>
*/
bool implEnsureTransformer() const;
};
diff --git a/forms/source/inc/FormComponent.hxx b/forms/source/inc/FormComponent.hxx
index 0c8b421008a3..42e79443279b 100644
--- a/forms/source/inc/FormComponent.hxx
+++ b/forms/source/inc/FormComponent.hxx
@@ -194,7 +194,7 @@ public:
@param _rAggregateService
the service name of the component to aggregate
@param _bSetDelegator
- set this to <FALSE/> if you don't want the constructor to set the delegator at
+ set this to <sal_False/> if you don't want the constructor to set the delegator at
the aggregate. In this case, you <em>have</em> to call doSetDelegator within your
own constructor.
@@ -202,7 +202,7 @@ public:
In this case, the aggregate needs to be queried for this interface <b>before</b> the
<member scope="com::sun::star::uno">XAggregation::setDelegator</member> call.
- In such a case, pass <FALSE/> to this parameter. Then, cache the aggregate's interface(s)
+ In such a case, pass <sal_False/> to this parameter. Then, cache the aggregate's interface(s)
as needed. Afterwards, call <member>doSetDelegator</member>.
In your destructor, you need to call <member>doResetDelegator</member> before
@@ -228,7 +228,7 @@ protected:
/** sets the control as delegator at the aggregate
This has to be called from within your derived class' constructor, if and only
- if you passed <FALSE/> to the <arg>_bSetDelegator</arg> parameter of the
+ if you passed <sal_False/> to the <arg>_bSetDelegator</arg> parameter of the
<type>OControl</type> constructor.
*/
void doSetDelegator();
@@ -383,13 +383,13 @@ protected:
const ::com::sun::star::uno::Reference< ::com::sun::star::lang::XMultiServiceFactory>& _rFactory, // factory to create the aggregate with
const ::rtl::OUString& _rUnoControlModelTypeName, // service name of te model to aggregate
const ::rtl::OUString& rDefault = ::rtl::OUString(), // service name of the default control
- const sal_Bool _bSetDelegator = sal_True // set to FALSE if you want to call setDelegator later (after returning from this ctor)
+ const sal_Bool _bSetDelegator = sal_True // set to sal_False if you want to call setDelegator later (after returning from this ctor)
);
OControlModel(
const OControlModel* _pOriginal, // the original object to clone
const ::com::sun::star::uno::Reference< ::com::sun::star::lang::XMultiServiceFactory>& _rFactory, // factory to create the aggregate with
const sal_Bool _bCloneAggregate = sal_True, // should the aggregate of the original be cloned, too?
- const sal_Bool _bSetDelegator = sal_True // set to FALSE if you want to call setDelegator later (after returning from this ctor)
+ const sal_Bool _bSetDelegator = sal_True // set to sal_False if you want to call setDelegator later (after returning from this ctor)
);
virtual ~OControlModel();
@@ -710,8 +710,8 @@ protected:
const ::rtl::OUString& _rUnoControlModelTypeName, // service name of te model to aggregate
const ::rtl::OUString& _rDefault, // service name of the default control
const sal_Bool _bCommitable, // is the control (model) commitable ?
- const sal_Bool _bSupportExternalBinding, // set to TRUE if you want to support XBindableValue
- const sal_Bool _bSupportsValidation // set to TRUE if you want to support XValidatable
+ const sal_Bool _bSupportExternalBinding, // set to sal_True if you want to support XBindableValue
+ const sal_Bool _bSupportsValidation // set to sal_True if you want to support XValidatable
);
OBoundControlModel(
const OBoundControlModel* _pOriginal, // the original object to clone
@@ -879,7 +879,7 @@ protected:
we're properly bound to a database column, especially <member>m_xColumnUpdate</member>
is not <NULL/>
@param _bPostReset
- <TRUE/> if and only if the current control value results from a reset (<member>getDefaultForReset</member>)
+ <sal_True/> if and only if the current control value results from a reset (<member>getDefaultForReset</member>)
@pure
*/
virtual sal_Bool commitControlValueToDbColumn(
@@ -1183,10 +1183,10 @@ private:
Use this method if there is a potential that <b>only</b> the validity flag changed. If
any of the other aspects (our current value, or our current text) changed, then
- pass <TRUE/> for <member>_bForceNotification</member>.
+ pass <sal_True/> for <member>_bForceNotification</member>.
@param _bForceNotification
- if <TRUE/>, then the validity listeners will be notified, not matter whether the validity
+ if <sal_True/>, then the validity listeners will be notified, not matter whether the validity
changed.
*/
void recheckValidity( bool _bForceNotification );
@@ -1217,8 +1217,8 @@ private:
@precond The control does not have an external value supplier
@param _bFromReload
- Determines whether the connection is made after the row set has been loaded (<FALSE/>)
- or reloaded (<TRUE/>)
+ Determines whether the connection is made after the row set has been loaded (<sal_False/>)
+ or reloaded (<sal_True/>)
@see impl_disconnectDatabaseColumn_noNotify
*/
@@ -1286,7 +1286,7 @@ private:
the binding which applies for being responsible for our value, Must not be
<NULL/>
@return
- <TRUE/> if and only if the given binding can supply values in the proper type
+ <sal_True/> if and only if the given binding can supply values in the proper type
@seealso getExternalValueType
*/